@@ -1,5 +1,5 @@
 package CPAN::Testers::Schema::Result::MetabaseUser;
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 # ABSTRACT: Legacy user information from the Metabase
 
 #pod =head1 SYNOPSIS
@@ -42,15 +42,12 @@ primary_column id => {
 #pod
 #pod =cut
 
-column resource => {
+unique_column resource => {
+    data_type => 'char',
+    size => 50,
     is_nullable => 0,
 };
 
-sub sqlt_deploy_hook {
-    my ($self, $sqlt_table) = @_;
-    $sqlt_table->add_index(name => 'ix_resource', fields => [qw( resource )]);
-}
-
 #pod =attr fullname
 #pod
 #pod The full name of the user.
@@ -85,7 +82,7 @@ CPAN::Testers::Schema::Result::MetabaseUser - Legacy user information from the M
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
